OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Naptár",
    "Individual" : "egyéni",
    "Group" : "Csoport",
    "Resource" : "Forrás",
    "Room" : "Szoba",
    "Unknown" : "Ismeretlen",
    "Required" : "Szükséges",
    "Optional" : "Opcionális",
    "Does not attend" : "Nem vesz részt",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ismeretlen időzónában tartózkodik ({tz}), visszaállítás UTC-re",
    "Please create a calendar first." : "Először naptárat készítsen",
    "New event" : "Új esemény",
    "Attendees" : "Résztvevők",
    "Reminders" : "Emlékeztetők",
    "Repeating" : "Ismétlődő",
    "When shared show full event" : "Megosztáskor mutassa a teljes eseményt.",
    "When shared show only busy" : "Megosztáskor csak a foglaltságot mutassa",
    "When shared hide this event" : "Megosztáskor rejtse el ezt az eseményt",
    "Please add a title!" : "Kérjük, töltse ki a címet!",
    "Please select a calendar!" : "Kérjük, válasszon egy naptárat!",
    "Global" : "Globális",
    "None" : "Egyik sem",
    "Every day" : "minden nap",
    "Every week" : "minden hét",
    "Every month" : "minden hónap",
    "Every year" : "minden év",
    "never" : "soha",
    "after" : "után",
    "At time of event" : "az eseménnyel egy időben",
    "5 minutes before" : "5 perccel előtte",
    "10 minutes before" : "10 perccel előtte",
    "15 minutes before" : "15 perccel előtte",
    "30 minutes before" : "30 perccel előtte",
    "1 hour before" : "1 órával előtte",
    "2 hours before" : "2 órával előtte",
    "Custom" : "egyéni",
    "Audio" : "Hang",
    "E Mail" : "E-mail",
    "Pop up" : "Felugró ablak",
    "sec" : "mp",
    "min" : "perc",
    "hours" : "óra",
    "days" : "nap",
    "week" : "hét",
    "before" : "előtte",
    "start" : "kezdet",
    "end" : "vég",
    "Editing reminders of unknown type not supported." : "Ismeretlen típusú emlékeztetős szerkesztése nem támogatott.",
    "Week {number} of {year}" : "{year} év {number}. hete",
    "Successfully imported" : "Sikeresen importálva!",
    "Partially imported, 1 failure" : "Részben importálva, 1 hiba",
    "Partially imported, {n} failures" : "Részben importálva, {n} hiba",
    "Audio alarm" : "Hangriasztás",
    "Pop-up" : "Felugró ablak",
    "E-Mail" : "E-mail",
    "{type} {time} before the event starts" : "{type} {time} idő múlva kezdődik az esemény",
    "{type} {time} before the event ends" : "{type} {time} idő múlva végződik az esemény",
    "{type} {time} after the event starts" : "{type} {time} esemény kezdete után",
    "{type} {time} after the event ends" : "{type} {time} esemény vége után",
    "{type} at the event's start" : "{type} az esemény kezdetekor",
    "{type} at the event's end" : "{type} az esemény végén",
    "{type} at {time}" : "{type} ekkor: {time}",
    "{calendar} shared by {owner}" : "{calendar} megosztója: {owner}",
    "Title of the Event" : "Az esemény címe",
    "starts" : "kezdete",
    "ends" : "vége",
    "All day Event" : "Mindennapos esemény",
    "Delete" : "Törlés",
    "Cancel" : "Mégsem",
    "More ..." : "Bővebben...",
    "Create" : "Létrehozás",
    "Update" : "Frissítés",
    "Close" : "Bezárás",
    "Location" : "Hely",
    "Description" : "Leírás",
    "Export" : "Exportálás",
    "Day" : "Nap",
    "Week" : "Hét",
    "Month" : "Hónap",
    "Today" : "Ma",
    "Share Calendar" : "A naptár megosztása",
    "More" : "Több",
    "Edit" : "Szerkesztés",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
    "can edit" : "szerkesztheti",
    "group" : "csoport",
    "New Calendar" : "Új naptár",
    "Subscriptions" : "Feliratkozások",
    "New Subscription" : "Új feliratkozás",
    "Url" : "Hivatkozás",
    "Edit event" : "Esemény szerkesztése",
    "Delete Event" : "Esemény törlése",
    "Save Event" : "Esemény mentése",
    "Time" : "Idő",
    "Type" : "Típus",
    "Relative" : "Relatív",
    "Absolute" : "Abszolút",
    "Repeat" : "Ismétlés",
    "times every" : "mindennyiszer",
    "Add" : "Hozzáadás",
    "E-Mail address of attendee" : "Résztvevők E-Mail címe",
    "Please add your email address in the personal settings in order to add attendees." : "Kérem adja meg az email címét a személyes beállításokban, hogy résztvevőket tudjon hozzáadni.",
    "from" : "feladó",
    "to" : "címzett",
    "This event's repeating rule is not supported yet." : "Ennek az eseménynek az ismétlődő szabálya még nem támogatott.",
    "Reset repeating rule" : "Ismétlődő szabály törlése",
    "Repeat every ..." : "Ismétlődjön minden ...",
    "end repeat ..." : "ismétlődés vége ...",
    "times" : "alkalommal",
    "Import Calendars" : "Naptár importálása",
    "Import canceled" : "Importálás megszakítva.",
    "Analyzing calendar" : "Naptár analizálása",
    "The file contains objects incompatible with the selected calendar" : "A fájlban olyan objektumok találhatók amik nem kompatibilisek a naptárral.",
    "New calendar" : "Új naptár",
    "Import scheduled" : "Importálás beütemezve",
    "Settings" : "Beállítások",
    "Import calendar" : "Naptár importálása",
    "No Calendars selected for import" : "Nincs importálásra kiválasztott naptár",
    "Primary CalDAV address" : "Elsődleges CalDAV cím",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV cím"
},
"nplurals=2; plural=(n != 1);");
